#!/bin/sh

#Build for Zenwalk Openbox 7.0: Markus Muttilainen
#source: http://ftp.gnome.org/pub/GNOME/sources/gnumeric/1.10/gnumeric-1.10.14.tar.bz2
(
set -e -x -u
CWD=`pwd`
PKG=/tmp/package-gnumeric

VERSION=1.10.14
ARCH=i486
BUILD=70.1

rm -rf $PKG
mkdir -p $PKG
cd /tmp
rm -rf gnumeric-$VERSION
tar xvf $CWD/gnumeric-$VERSION.tar.bz2
cd gnumeric-$VERSION
chown -R root.root .
find . -perm 777 -exec chmod 755 {} \;
find . -perm 664 -exec chmod 644 {} \;
./configure \
  --prefix=/usr \
  --sysconfdir=/etc \
  --localstatedir=/var/lib \
  --mandir=/usr/man \
  --enable-ssindex \
  --with-python \
  --with-gda \
  --with-guile \
  --with-perl \
  --with-gb \
  --without-gnome \
  --disable-scrollkeeper

make
make -C doc html
make install DESTDIR=$PKG
( cd $PKG
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs -r strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs -r strip --strip-unneeded 2> /dev/null
)

gzip -9 $PKG/usr/man/*/*

if [ -d $PKG/usr/share/doc ]; then
   mv $PKG/usr/share/doc $PKG/usr
fi

mkdir -p $PKG/install

# redundant scrollkeeper
if [ -d ${PKG}/var/scrollkeeper ]; then
	rm -r ${PKG}/var/scrollkeeper
fi
if [ -d ${PKG}/var/lib/scrollkeeper ]; then
	rm -r ${PKG}/var/lib/scrollkeeper
fi
set +e
mkdir -p $PKG/usr/doc/gnumeric-$VERSION
cp -av $CWD/gnumeric-$VERSION/{AUTHORS,BEVERAGES,BUGS,COPYING,ChangeLog,HACKING,INSTALL,MAINTAINERS,NEWS,README} $PKG/usr/doc/gnumeric-$VERSION

mkdir -p $PKG/usr/src/gnumeric-$VERSION
cp $CWD/build-gnumeric.sh $PKG/usr/src/gnumeric-$VERSION/

cat <<"EOF" > $PKG/install/doinst.sh
# Update the scrollkeeper database (Remove stale pieces)
if [ -x usr/bin/scrollkeeper-update ]; then
        usr/bin/scrollkeeper-update > /dev/null 2>&1
fi
EOF

#
# make a slack-desc file
#
cat <<"EOF" > $PKG/install/slack-desc
# HOW TO EDIT THIS FILE:
# The "handy ruler" below makes it easier to edit a package description.  Line
# up the first '|' above the ':' following the base package name, and the '|' on
# the right side marks the last column you can put a character in.  You must make
# exactly 11 lines for the formatting to be correct.  It's also customary to
# leave one space after the ':'.

        |-----handy-ruler------------------------------------------------------|
gnumeric: gnumeric (spreadsheet application)
gnumeric:
gnumeric: This project aims to become a drop in replacement for
gnumeric: proprietary spreadsheets.  Gnumeric is still a young
gnumeric: program and it is advancing steadily.
gnumeric:
gnumeric:
gnumeric:
gnumeric:
gnumeric:
gnumeric:
EOF

#> helperline
(cd $PKG;find . -printf "%y %m %u:%g %p %l\n") >$CWD/pkgtree.log

cd $PKG
makepkg -l y -c n ../gnumeric-$VERSION-$ARCH-$BUILD.txz
cd ..
md5sum gnumeric-$VERSION-$ARCH-$BUILD.txz > gnumeric-$VERSION-$ARCH-$BUILD.md5

) 2>&1 | tee gnumeric-build-log.txt
